summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qmenuitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qmenuitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qmenuitem_imp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kjsembed/qtbindings/qmenuitem_imp.h b/kjsembed/qtbindings/qmenuitem_imp.h
index ad1e480b..9739d078 100644
--- a/kjsembed/qtbindings/qmenuitem_imp.h
+++ b/kjsembed/qtbindings/qmenuitem_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TTQMenuItem;
+class TQMenuItem;
/**
* Namespace containing the KJSEmbed library.
@@ -17,7 +17,7 @@ class TTQMenuItem;
namespace KJSEmbed {
/**
* Wrapper class for TTQMenuItem methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -72,7 +72,7 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TTQMenuItem *toTQMenuItem( KJS::Object &object );
+ static TQMenuItem *toTQMenuItem( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -122,7 +122,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TTQMenuItem *instance; // Temp
+ TQMenuItem *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class TTQMenuItem;
namespace KJSEmbed {
/**
- * Wrapper class for TTQMenuItem methods.
+ * Wrapper class for TQMenuItem methods.
*
* @author Richard Moore, rich@kde.org